# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-27 01:22
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_dpa_chile', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='comuna',
            name='region',
            field=models.ForeignKey(default=None, on_delete=django.db.models.deletion.CASCADE, to='django_dpa_chile.Region'),
            preserve_default=False,
        ),
    ]
